==> haskell-placeholders-0.1-23-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-placeholders.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 placeholders
version:              0.1
visibility:           public
id:                   placeholders-0.1-D8Qu20gir4qKJsaaA6RSJR
key:                  placeholders-0.1-D8Qu20gir4qKJsaaA6RSJR
license:              BSD-3-Clause
copyright:            (c) 2011 Andreas Hammar
maintainer:           Andreas Hammar <ahammar@gmail.com>
author:               Andreas Hammar
homepage:             http://github.com/ahammar/placeholders
synopsis:             Placeholders for use while developing Haskell code
description:
    While working on some Haskell code, it is often useful to
    work incrementally by inserting @undefined@ as a
    placeholder for missing code.

    This library provides placeholders that produce better
    messages when evaluated at run-time and also generate
    compile-time warnings so that they do not get forgotten
    so easily.
    For details, see <http://github.com/ahammar/placeholders>

category:             Development
abi:                  966593a32c4dcfee41e90bb4bb94e75f
exposed:              True
exposed-modules:      Development.Placeholders
import-dirs:          /usr/lib/ghc-9.0.1/site-local/placeholders-0.1
library-dirs:         /usr/lib/ghc-9.0.1/site-local/placeholders-0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/placeholders-0.1
hs-libraries:         HSplaceholders-0.1-D8Qu20gir4qKJsaaA6RSJR
depends:              base-4.15.0.0 template-haskell-2.17.0.0
haddock-interfaces:
    /usr/share/doc/haskell-placeholders/html/placeholders.haddock

haddock-html:         /usr/share/doc/haskell-placeholders/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-placeholders-0.1-24-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-placeholders.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 placeholders
version:              0.1
visibility:           public
id:                   placeholders-0.1-BA9VozVXgimDA3AHSiE2jW
key:                  placeholders-0.1-BA9VozVXgimDA3AHSiE2jW
license:              BSD-3-Clause
copyright:            (c) 2011 Andreas Hammar
maintainer:           Andreas Hammar <ahammar@gmail.com>
author:               Andreas Hammar
homepage:             http://github.com/ahammar/placeholders
synopsis:             Placeholders for use while developing Haskell code
description:
    While working on some Haskell code, it is often useful to
    work incrementally by inserting @undefined@ as a
    placeholder for missing code.

    This library provides placeholders that produce better
    messages when evaluated at run-time and also generate
    compile-time warnings so that they do not get forgotten
    so easily.
    For details, see <http://github.com/ahammar/placeholders>

category:             Development
abi:                  5984abf4f6ddfb9ed8d6914566abc1c7
exposed:              True
exposed-modules:      Development.Placeholders
import-dirs:          /usr/lib/ghc-9.0.2/site-local/placeholders-0.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/placeholders-0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/placeholders-0.1
hs-libraries:         HSplaceholders-0.1-BA9VozVXgimDA3AHSiE2jW
depends:              base-4.15.1.0 template-haskell-2.17.0.0
haddock-interfaces:
    /usr/share/doc/haskell-placeholders/html/placeholders.haddock

haddock-html:         /usr/share/doc/haskell-placeholders/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
